#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


from pyramid.i18n import TranslationStringFactory
_ = TranslationStringFactory('pyams_thesaurus')


def includeme(config):
    """Pyramid include"""

    from .include import include_package
    include_package(config)

    # register custom permissions
    config.register_permission({'id': 'thesaurus.admin',
                                'title': _("Manage thesaurus properties")})
    config.register_permission({'id': 'thesaurus.manage',
                                'title': _("Manage thesaurus content")})
    config.register_permission({'id': 'thesaurus.extract.manage',
                                'title': _("Manage thesaurus extract")})

    # register custom roles
    config.register_role({'id': 'thesaurus.Admin',
                          'title': _("Thesaurus administrator (role)"),
                          'permissions': {'thesaurus.admin', 'thesaurus.manage', 'thesaurus.extract.manage',
                                          'view', 'system.view'},
                          'managers': {'system:admin', 'role:system.Manager'}})
    config.register_role({'id': 'thesaurus.Manager',
                          'title': _("Thesaurus content manager (role)"),
                          'permissions': {'thesaurus.manage', 'thesaurus.extract.manage', 'view', 'system.view'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:thesaurus.Admin'}})
    config.register_role({'id': 'thesaurus.ExtractManager',
                          'title': _("Thesaurus extract manager (role)"),
                          'permissions': {'thesaurus.extract.manage', 'view', 'system.view'},
                          'managers': {'system:admin', 'role:system.Manager', 'role:thesaurus.Admin'}})
